Struct google_admin1_reports::UsageReportEntity [−][src]
pub struct UsageReportEntity {
pub profile_id: Option<String>,
pub user_email: Option<String>,
pub type_: Option<String>,
pub entity_id: Option<String>,
pub customer_id: Option<String>,
}Information about the type of the item.
This type is not used in any activity, and only used as part of another schema.
Fields
profile_id: Option<String>
Obfuscated user id for the record.
user_email: Option<String>
user's email. Only relevant if entity.type = "USER"
type_: Option<String>
The type of item, can be customer, user, or entity (aka. object).
entity_id: Option<String>
Object key. Only relevant if entity.type = "OBJECT" Note: external-facing name of report is "Entities" rather than "Objects".
customer_id: Option<String>
Obfuscated customer id for the record.