Struct google_admin1_reports::UsageReports [−][src]
pub struct UsageReports {
pub next_page_token: Option<String>,
pub kind: Option<String>,
pub etag: Option<String>,
pub usage_reports: Option<Vec<UsageReport>>,
pub warnings: Option<Vec<UsageReportsWarnings>>,
}JSON template for a collection of usage reports.
Activities
This type is used in activities, which are methods you may call on this type or where this type is involved in. The list links the activity name, along with information about where it is used (one of request and response).
- get user usage report (response)
- get entity usage reports (response)
- get customer usage reports (response)
Fields
next_page_token: Option<String>
Token for retrieving the next page
kind: Option<String>
The kind of object.
etag: Option<String>
ETag of the resource.
usage_reports: Option<Vec<UsageReport>>
Various application parameter records.
warnings: Option<Vec<UsageReportsWarnings>>
Warnings if any.